pub struct Position(pub Vector);Expand description
The global position of a rigid body or a collider.
Relation to Transform and GlobalTransform
Position is used for physics internally and kept in sync with Transform
by the PhysicsTransformPlugin. It rarely needs to be used directly in your own code, as Transform can still
be used for almost everything. Using Position should only be required for managing positions
in systems running in the SubstepSchedule. However, if you prefer, you can also use Position
for everything.
The reasons why the engine uses a separate Position component can be found
here.
Example
use avian2d::prelude::*;
use bevy::prelude::*;
fn setup(mut commands: Commands) {
commands.spawn((
RigidBody::Dynamic,
Position::from_xy(0.0, 20.0),
));
}Tuple Fields
0: VectorImplementations
Sourceimpl Position
impl Position
Sourcepub const PLACEHOLDER: Self
pub const PLACEHOLDER: Self
A placeholder position. This is an invalid position and should not be used to an actually position entities in the world, but can be used to indicate that a position has not yet been initialized.
Methods from Deref<Target = Vector>
pub const ZERO: Vec2
pub const ONE: Vec2
pub const NEG_ONE: Vec2
pub const MIN: Vec2
pub const MAX: Vec2
pub const NAN: Vec2
pub const INFINITY: Vec2
pub const NEG_INFINITY: Vec2
pub const X: Vec2
pub const Y: Vec2
pub const NEG_X: Vec2
pub const NEG_Y: Vec2
pub const AXES: [Vec2; 2]
pub const USES_CORE_SIMD: bool = false
pub const USES_NEON: bool = false
pub const USES_SCALAR_MATH: bool = true
pub const USES_SSE2: bool = false
pub const USES_WASM_SIMD: bool = false
pub const USES_WASM32_SIMD: bool = false